#!/bin/sh

/bin/rm -rf ${DESTDIR}

make -C mozilla install \
    BUILD_OFFICIAL=1 \
    MOZILLA_OFFICIAL=1 \
    DESTDIR=${DESTDIR}

# NSS and NSPR are both installed into ${PREFIX}/lib instead of
# ${PREFIX}/lib/mozilla-VERSION

OLDCWD=`pwd`
cd ${DESTDIR}${PREFIX}/lib/mozilla-${VERSION}
# copy nspr
mv -v \
  libnspr4.so libplc4.so libplds4.so \
  ${DESTDIR}${PREFIX}/lib/

# copy nss
mv -v \
  libnss3.so libsmime3.so libsoftokn3.so libssl3.so \
  ${DESTDIR}${PREFIX}/lib/

# copy system libs
mv -v \
  libgkgfx.so libjsj.so libmozjs.so libxpcom.so \
  libgtkembedmoz.so libgtksuperwin.so libgtkxtbin.so \
  ${DESTDIR}${PREFIX}/lib/

# libnssckbi.so must be in both places
cp -v libnssckbi.so ${DESTDIR}${PREFIX}/lib/

# solaris has extra libraries
for lib in libfreebl_hybrid_3.so libfreebl_pure32_3.so; do
	if [ -f ${DESTDIR}${PREFIX}/lib/mozilla-${VERSION}/$lib ];
	then
	    mv ${DESTDIR}${PREFIX}/lib/mozilla-${VERSION}/$lib \
	       ${DESTDIR}${PREFIX}/lib/;
	fi
done

cd ${OLDPWD}


# build our initial component and chrome registry
# we don't need to do this anymore

OLDPWD=`pwd`
  cd ${DESTDIR}${PREFIX}/lib/mozilla-${VERSION}
  # register our components
  LD_LIBRARY_PATH=`pwd`:`pwd`/..:${PREFIX}/lib:${LD_LIBRARY_PATH} \
    MOZILLA_FIVE_HOME=`pwd` ./regxpcom
  # set up the default skin and locale to trigger the generation of
  # the user-locales and users-skins.rdf
  echo "skin,install,select,classic/1.0" >> chrome/installed-chrome.txt
  echo "locale,install,select,en-US" >> chrome/installed-chrome.txt
  # set up the chrome rdf files 
  LD_LIBRARY_PATH=`pwd`:`pwd`/..:${PREFIX}/lib:${LD_LIBRARY_PATH} \
    MOZILLA_FIVE_HOME=`pwd` ./regchrome
  # fix permissions of the chrome directories
  /usr/bin/find . -type d -perm 0700 -exec chmod 755 {} \; || :
cd ${OLDPWD}

# cp -L (dereference all symlinks) is required for fileutils >= 2.0.27
# (POSIX compliance); prior versions don't understand -L, so fall back...

# copy the nss files to the right place
mkdir ${DESTDIR}${PREFIX}/include/mozilla-${VERSION}/nss/

/usr/bin/find mozilla/security/nss/lib/ -name '*.h' -type f -exec /bin/cp {} \
 ${DESTDIR}${PREFIX}/include/mozilla-${VERSION}/nss/ \;

# copy our devel tools
install -c -m 755 \
    mozilla/dist/bin/xpcshell \
    mozilla/dist/bin/xpidl \
    mozilla/dist/bin/xpt_dump \
    mozilla/dist/bin/xpt_link \
    ${DESTDIR}${PREFIX}/lib/mozilla-${VERSION}

# set up our desktop files
DESKTOP_FILES="Mozilla.desktop Mozilla-chatzilla.desktop Mozilla-composer.desktop Mozilla-mail.desktop Mozilla-news.desktop"

/bin/mkdir -p ${DESTDIR}${PREFIX}/share/gnome/apps/Internet
/bin/mkdir -p ${DESTDIR}/etc/X11/applnk/Internet

for file in ${DESKTOP_FILES}; do
    install -c -m 644 mozilla-desktop-files/$file \
	${DESTDIR}${PREFIX}/share/gnome/apps/Internet/$file
    install -c -m 644 mozilla-desktop-files/$file \
	${DESTDIR}/etc/X11/applnk/Internet/$file
done

# our icons are better!
#install -c -m 644 %{SOURCE9} ${DESTDIR}${PREFIX}/lib/mozilla-${VERSION}/icons/
#install -c -m 644 %{SOURCE10} ${DESTDIR}${PREFIX}/lib/mozilla-${VERSION}/icons/

# install our mozilla.sh file
cat mozilla.sh.in | \
    sed -e "s/MOZILLA_VERSION/${VERSION}/g" \
	-e "s#MYPREFIX#${PREFIX}#g" > \
  ${DESTDIR}${PREFIX}/bin/mozilla

chmod 755 ${DESTDIR}${PREFIX}/bin/mozilla

# install our rebuild file
cat mozilla-rebuild-databases.pl.in | \
    sed -e "s/MOZILLA_VERSION/${VERSION}/g" \
	-e "s#MYPREFIX#${PREFIX}#g" > \
  ${DESTDIR}${PREFIX}/lib/mozilla-${VERSION}/mozilla-rebuild-databases.pl

chmod 755 \
  ${DESTDIR}${PREFIX}/lib/mozilla-${VERSION}/mozilla-rebuild-databases.pl


# I can't believe I'm doing this
for lib in libasn1.a libnssb.a libcertdb.a libcerthi.a libnssckfw.a \
	 libcrmf.a libcryptohi.a libnssdev.a libswfci.a libfreebl.a \
	 libjar.a libnss.a libpk11wrap.a libpkcs12.a libpkcs7.a \
	 libnsspki.a libpki1.a libsmime.a libsoftokn.a libssl.a libsecutil.a \
	 libnspr4.a libplds4.a libplc4.a; do
    install -m 644 -c mozilla/dist/lib/$lib \
	${DESTDIR}${PREFIX}/lib/mozilla-${VERSION}
done

# kill all the empty directories
find ${DESTDIR} -type d -depth -empty | xargs rmdir -p 2>/dev/null || :
